# automatically generated by the FlatBuffers compiler, do not modify

# namespace: flatbuf

# The varieties of relations
class RelationImpl(object):
    NONE = 0
    Aggregate = 1
    Filter = 2
    Join = 3
    Limit = 4
    LiteralRelation = 5
    OrderBy = 6
    Project = 7
    SetOperation = 8
    Source = 9

