# automatically generated by the FlatBuffers compiler, do not modify

# namespace: flatbuf

# ----------------------------------------------------------------------
# Dictionary encoding metadata
# Maintained for forwards compatibility, in the future
# Dictionaries might be explicit maps between integers and values
# allowing for non-contiguous index values
class DictionaryKind(object):
    DenseArray = 0

