# automatically generated by the FlatBuffers compiler, do not modify

# namespace: flatbuf

# ----------------------------------------------------------------------
# Endianness of the platform producing the data
class Endianness(object):
    Little = 0
    Big = 1

