# automatically generated by the FlatBuffers compiler, do not modify

# namespace: flatbuf

# The kind of set operation being performed.
class SetOpKind(object):
    Union = 0
    Intersection = 1
    Difference = 2

