# automatically generated by the FlatBuffers compiler, do not modify

# namespace: tabular

import flatbuffers
from flatbuffers.compat import import_numpy
np = import_numpy()

class GetProjectionTableStatsResponse(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAs(cls, buf, offset=0):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = GetProjectionTableStatsResponse()
        x.Init(buf, n + offset)
        return x

    @classmethod
    def GetRootAsGetProjectionTableStatsResponse(cls, buf, offset=0):
        """This method is deprecated. Please switch to GetRootAs."""
        return cls.GetRootAs(buf, offset)
    # GetProjectionTableStatsResponse
    def Init(self, buf, pos):
        self._tab = flatbuffers.table.Table(buf, pos)

    # GetProjectionTableStatsResponse
    def NumRows(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int64Flags, o + self._tab.Pos)
        return 0

    # GetProjectionTableStatsResponse
    def SizeInBytes(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int64Flags, o + self._tab.Pos)
        return 0

    # GetProjectionTableStatsResponse
    def DirtyBlocksPercentage(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(8))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int64Flags, o + self._tab.Pos)
        return 0

    # GetProjectionTableStatsResponse
    def InitialSyncProgress(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int64Flags, o + self._tab.Pos)
        return 0

def Start(builder): builder.StartObject(4)
def GetProjectionTableStatsResponseStart(builder):
    """This method is deprecated. Please switch to Start."""
    return Start(builder)
def AddNumRows(builder, numRows): builder.PrependInt64Slot(0, numRows, 0)
def GetProjectionTableStatsResponseAddNumRows(builder, numRows):
    """This method is deprecated. Please switch to AddNumRows."""
    return AddNumRows(builder, numRows)
def AddSizeInBytes(builder, sizeInBytes): builder.PrependInt64Slot(1, sizeInBytes, 0)
def GetProjectionTableStatsResponseAddSizeInBytes(builder, sizeInBytes):
    """This method is deprecated. Please switch to AddSizeInBytes."""
    return AddSizeInBytes(builder, sizeInBytes)
def AddDirtyBlocksPercentage(builder, dirtyBlocksPercentage): builder.PrependInt64Slot(2, dirtyBlocksPercentage, 0)
def GetProjectionTableStatsResponseAddDirtyBlocksPercentage(builder, dirtyBlocksPercentage):
    """This method is deprecated. Please switch to AddDirtyBlocksPercentage."""
    return AddDirtyBlocksPercentage(builder, dirtyBlocksPercentage)
def AddInitialSyncProgress(builder, initialSyncProgress): builder.PrependInt64Slot(3, initialSyncProgress, 0)
def GetProjectionTableStatsResponseAddInitialSyncProgress(builder, initialSyncProgress):
    """This method is deprecated. Please switch to AddInitialSyncProgress."""
    return AddInitialSyncProgress(builder, initialSyncProgress)
def End(builder): return builder.EndObject()
def GetProjectionTableStatsResponseEnd(builder):
    """This method is deprecated. Please switch to End."""
    return End(builder)