# automatically generated by the FlatBuffers compiler, do not modify

# namespace: flatbuf

import flatbuffers
from flatbuffers.compat import import_numpy
np = import_numpy()

# An expression with an order
class SortKey(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAs(cls, buf, offset=0):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = SortKey()
        x.Init(buf, n + offset)
        return x

    @classmethod
    def GetRootAsSortKey(cls, buf, offset=0):
        """This method is deprecated. Please switch to GetRootAs."""
        return cls.GetRootAs(buf, offset)
    # SortKey
    def Init(self, buf, pos):
        self._tab = flatbuffers.table.Table(buf, pos)

    # SortKey
    def Expression(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            x = self._tab.Indirect(o + self._tab.Pos)
            from vastdb.vast_flatbuf.org.apache.arrow.computeir.flatbuf.Expression import Expression
            obj = Expression()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # SortKey
    def Ordering(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Uint8Flags, o + self._tab.Pos)
        return 0

def Start(builder): builder.StartObject(2)
def SortKeyStart(builder):
    """This method is deprecated. Please switch to Start."""
    return Start(builder)
def AddExpression(builder, expression): builder.PrependUOffsetTRelativeSlot(0, flatbuffers.number_types.UOffsetTFlags.py_type(expression), 0)
def SortKeyAddExpression(builder, expression):
    """This method is deprecated. Please switch to AddExpression."""
    return AddExpression(builder, expression)
def AddOrdering(builder, ordering): builder.PrependUint8Slot(1, ordering, 0)
def SortKeyAddOrdering(builder, ordering):
    """This method is deprecated. Please switch to AddOrdering."""
    return AddOrdering(builder, ordering)
def End(builder): return builder.EndObject()
def SortKeyEnd(builder):
    """This method is deprecated. Please switch to End."""
    return End(builder)