# automatically generated by the FlatBuffers compiler, do not modify

# namespace: flatbuf

# Whether lesser values should precede greater or vice versa,
# also whether nulls should preced or follow values
class Ordering(object):
    ASCENDING_THEN_NULLS = 0
    DESCENDING_THEN_NULLS = 1
    NULLS_THEN_ASCENDING = 2
    NULLS_THEN_DESCENDING = 3

